@@ -3,7 +3,7 @@ package Tk::More;
 use strict;
 use vars qw($VERSION @ISA);
 
-$VERSION = sprintf("%d.%02d", q$Revision: 5.5 $ =~ /(\d+)\.(\d+)/);
+$VERSION = sprintf("%d.%02d", q$Revision: 5.7 $ =~ /(\d+)\.(\d+)/);
 
 use Tk qw(Ev);
 use Tk::Derived;
@@ -45,8 +45,15 @@ sub Populate {
     $cw->Advertise('text' => $t);
     $t->tagConfigure('search', -foreground => 'red');
 
-    # reorder bindings: private widget bindings first
-    $t->bindtags([$t, grep { $_ ne $t->PathName } $t->bindtags]);
+    # reorder bindings: toplevel and private widget bindings first
+    #
+    # The theory behind it: every event not overwritten and marked
+    # with Tk->break will in the end be handled by ROText. Often it is
+    # likely that some "application" bindings should win over the
+    # ROText. In fact, most keyboard bindings of ROText (besides
+    # cursor keys) are not useful in this context. So let the
+    # application's bindings win.
+    $t->bindtags([$cw->parent->toplevel, $t, grep { $_ ne $t->PathName } $t->bindtags]);
 
     $t->bind('<Key-slash>',    [$cw, 'Search', 'Next']);
     $t->bind('<Key-question>', [$cw, 'Search', 'Prev']);
@@ -99,6 +106,7 @@ sub Populate {
 		   'Search'    => 'SELF',
 		   'ShowMatch' => 'SELF',
 		   'Load'      => 'SELF',
+		   'LoadFH'    => 'SELF',
 		   'AddQuitBindings' => 'SELF',
 		  );
 
@@ -196,25 +204,10 @@ sub ShowMatch {
 sub Load
 {
  my ($text,$file,%args) = @_;
- my $encoding = delete $args{-encoding};
- die "Unhandled arguments: " . join(" ", %args) if %args;
  if (open(FILE,"<$file"))
   {
-   if ($encoding)
-    {
-     binmode FILE, ":encoding($encoding)";
-    }
-   $text->MainWindow->Busy;
-   $text->SUPER::delete('1.0','end');
-   #yy delete $text->{UNDO};
-   while (<FILE>)
-    {
-     $text->SUPER::insert('end',$_);
-    }
+   $text->LoadFH(\*FILE,%args);
    close(FILE);
-   #yy $text->{FILE} = $file;
-   $text->markSet('insert', '@1,0');
-   $text->MainWindow->Unbusy;
   }
  else
   {
@@ -223,6 +216,27 @@ sub Load
   }
 }
 
+sub LoadFH
+{
+ my ($text,$fh,%args) = @_;
+ my $encoding = delete $args{-encoding};
+ die "Unhandled arguments: " . join(" ", %args) if %args;
+ if ($encoding)
+  {
+   binmode $fh, ":encoding($encoding)";
+  }
+ $text->MainWindow->Busy;
+ $text->SUPER::delete('1.0','end');
+ #yy delete $text->{UNDO};
+ while (<$fh>)
+  {
+   $text->SUPER::insert('end',$_);
+  }
+ #yy $text->{FILE} = $file;
+ $text->markSet('insert', '@1,0');
+ $text->MainWindow->Unbusy;
+}
+
 # search_text copied from demo search.pl (modified)
 sub search_text {
 
